@@ -1,11 +1,11 @@
-/* $Id: maildirClient.c,v 1.12 2002/10/14 05:52:26 bluehal Exp $ */
+/* $Id: maildirClient.c,v 1.15 2004/03/28 00:28:58 bluehal Exp $ */
 /* Author : Yong-iL Joh ( tolkien@mizi.com )
    Modified : Jorge Garca ( Jorge.Garcia@uv.es )
    Modified : Dwayne C. Litzenberger ( dlitz@dlitz.net )
  * 
  * Maildir checker.
  *
- * Last Updated : $Date: 2002/10/14 05:52:26 $
+ * Last Updated : $Date: 2004/03/28 00:28:58 $
  *
  */
 
@@ -15,6 +15,7 @@
 
 #include "Client.h"
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <dirent.h>
 #include <errno.h>
 #include <utime.h>
@@ -54,7 +55,7 @@ int maildirCheckHistory(Pop3 pc)
 	struct stat st_new;
 	struct stat st_cur;
 	struct utimbuf ut;
-	char path_new[256], path_cur[256];
+	char path_new[BUF_BIG * 2], path_cur[BUF_BIG * 2];
 
 	int count_new = 0, count_cur = 0;
 
@@ -68,7 +69,7 @@ int maildirCheckHistory(Pop3 pc)
 	if (pc->u.maildir.dircache_flush) {
 		/* hack to clear directory cache for network-mounted maildirs */
 		int fd;
-		char path_newtmp[512];
+		char path_newtmp[BUF_BIG * 2 + 32];
 		strcpy(path_newtmp, path_new);
 		strcat(path_newtmp, ".wmbiff.dircache_flush.XXXXXX");
 		if ((fd = mkstemp(path_newtmp)) >= 0) {
@@ -76,8 +77,8 @@ int maildirCheckHistory(Pop3 pc)
 			unlink(path_newtmp);
 		} else {
 			DM(pc, DEBUG_ERROR,
-			   "Can't create dircache flush file '%s': %s\n", path_newtmp,
-			   strerror(errno));
+			   "Can't create dircache flush file '%s': %s\n",
+			   path_newtmp, strerror(errno));
 		}
 	}
 
@@ -163,7 +164,12 @@ int maildirCreate(Pop3 pc, const char *str)
 	} else {
 		i = 0;
 	}
-	strcpy(pc->path, str + 8 + i);	/* cut off ``maildir:'' */
+	if (strlen(str + 8 + i) + 1 > BUF_BIG) {
+		DM(pc, DEBUG_ERROR, "maildir '%s' is too long.\n", str + 8 + i);
+		memset(pc->path, 0, BUF_BIG);
+	} else {
+		strncpy(pc->path, str + 8 + i, BUF_BIG - 1);	/* cut off ``maildir:'' */
+	}
 
 	DM(pc, DEBUG_INFO, "maildir: str = '%s'\n", str);
 	DM(pc, DEBUG_INFO, "maildir: path= '%s'\n", pc->path);
