@@ -21,6 +21,7 @@
 #include "Client.h"
 #include "passwordMgr.h"
 #include "tlsComm.h"
+#include "charutil.h"
 
 int debug_default = DEBUG_INFO;
 int Relax = 1;
@@ -57,7 +58,7 @@ int test_backtickExpand(void)
 }
 
 #define CKSTRING(x,shouldbe) if(strcmp(x,shouldbe)) { \
-printf("Failed: expected '" #shouldbe "' but got '%s'\n", x); \
+printf("FAILED: expected '" #shouldbe "' but got '%s'\n", x); \
  return 1; } else { printf("good: '" shouldbe "' == '%s'\n", x); }
 
 /* return 1 if fail, 0 if success */
@@ -188,6 +189,15 @@ int test_imap4creator(void)
 	CKSTRING(m.u.pop_imap.serverName, "bar");
 	CKINT(m.u.pop_imap.serverPort, 143);
 
+	if (imap4Create(&m, "imap:foo:@192.168.1.1/\"mybox\"")) {
+		printf
+			("FAILED: to create IMAP box with IP address for servername\n");
+		return 1;
+	}
+	CKSTRING(m.path, "\"mybox\"");
+	CKSTRING(m.u.pop_imap.serverName, "192.168.1.1");
+	CKINT(m.u.pop_imap.serverPort, 143);
+
 	if (imap4Create(&m, "imap:foo:@bar/\"space box\"")) {
 		return 1;
 	}
@@ -316,6 +326,62 @@ int test_getline_from_buffer(void)
 	return (0);
 }
 
+int test_charutil(void)
+{
+
+	char *v = strdup("abc#def");
+
+	StripComment(v);
+	if (strcmp(v, "abc#def") != 0) {
+		printf("FAILURE: comment stripper stripped when it shouldn't\n");
+		return 1;
+	}
+
+	v = strdup("abc #def");
+
+	StripComment(v);
+	if (strcmp(v, "abc ") != 0) {
+		printf("FAILURE: comment stripper should've stripped\n");
+		return 1;
+	}
+
+
+	return 0;
+}
+
+#include <netinet/in.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+int test_sock_connect(void)
+{
+	struct sockaddr_in addr;
+	int s = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
+	int addrlen = sizeof(struct sockaddr_in);
+	if (s < 0) {
+		perror("socket");
+		return 1;
+	}
+	addr.sin_family = AF_INET;
+	addr.sin_addr.s_addr = 0;
+	addr.sin_port = 0;
+	if (bind(s, &addr, sizeof(struct sockaddr_in)) < 0) {
+		perror("bind");
+		return 1;
+	}
+	getsockname(s, &addr, &addrlen);
+	if (listen(s, 5) < 0) {
+		perror("listen");
+		return 1;
+	}
+	if (sock_connect("127.0.0.1", htons(addr.sin_port)) < 0) {
+		return 1;
+	}
+	if (sock_connect("localhost", htons(addr.sin_port)) < 0) {
+		return 1;
+	}
+	return 0;
+}
+
 
 int print_info(UNUSED(void *state))
 {
@@ -352,6 +418,11 @@ int main(UNUSED(int argc), UNUSED(char *argv[]))
 		exit(EXIT_FAILURE);
 	}
 
+	if (test_sock_connect()) {
+		printf("SOME TESTS FAILED!\n");
+		exit(EXIT_FAILURE);
+	}
+
 	Relax = 1;
 	if (test_imap4creator()) {
 		printf("SOME TESTS FAILED!\n");
@@ -363,6 +434,16 @@ int main(UNUSED(int argc), UNUSED(char *argv[]))
 		exit(EXIT_FAILURE);
 	}
 
+	if (test_charutil()) {
+		printf("SOME TESTS FAILED!\n");
+		exit(EXIT_FAILURE);
+	}
+
+	if (test_sock_connect()) {
+		printf("SOME TESTS FAILED!\n");
+		exit(EXIT_FAILURE);
+	}
+
 	printf("Success! on all tests.\n");
 	exit(EXIT_SUCCESS);
 }
